function Remove-RepositoryModule
{
    param ($protectedModulesPath, $respositoryPath, $packageName)

    # Validate that the package name parameter exists
    if ($packageName -eq $null -or $packageName -eq "")
    {
        throw (New-Object ArgumentException("The package name was not specified."))
    }

    # Get the package.config content .. so we can construct ModuleRepository folder path 
    $packageConfigPath = Join-Path $protectedModulesPath "packages.config"

	if(!(Test-Path $packageConfigPath)) 
	{
    	return	 
	}
    
    # Load the packages.config as an XmlDocument
    [xml] $packagesConfig = Get-Content $packageConfigPath 

    if($packagesConfig -ne $null)
    {
        # we could have several versions of a package so get all and then delete one by one
        $packageElements = $packagesConfig.SelectNodes("/packages/package[@id=""$packageName""]")
        if($packageElements -ne $null)
        {
            foreach($package in $packageElements)
            {
                $folderName = $package.id + "."+ $package.version
                $repositoryModulePath = (Join-Path $respositoryPath $folderName)

                # If the add-on folder doesn't exist then don't need to delete anything and we exit silently
                if ((Test-Path $repositoryModulePath))
                {
                    try
                    {
                        # Remove the add-on folder and all children.
                        Write-Host "Removing folder - $repositoryModulePath"
                        Remove-Item $repositoryModulePath -Force -Recurse -ErrorAction Stop
                    }
                    catch [Exception]
                    {
                        # Show a message box explaining that the package.config couldn't be saved
                        $errorMsg = "The package installer was unable to delete the folder ""$repositoryModulePath"". Please delete this folder and its contents manually."
                        Write-Host $errorMsg
                        [System.Windows.Forms.MessageBox]::Show($errorMsg, "Error Deleting Repository Module") | Out-Null
                    }   
                }
            }            
        }        
    }
}

Export-ModuleMember -Function Remove-RepositoryModule